@@ -2,7 +2,6 @@ from zope.interface import implements
 from zope.component import getMultiAdapter, queryUtility
 
 from z3c.form import form, field, button
-from z3c.form.browser.text import TextFieldWidget
 from z3c.form.interfaces import HIDDEN_MODE
 from plone.app.z3cform.layout import wrap_form, FormWrapper
 
@@ -68,7 +67,6 @@ class AddTagForm(form.EditForm):
             id = request.form[id_field]
             tag = self.manager.get_tag(id, False)
             if not tag is None:
-                prefix = '%swidgets' % (self.prefix)
                 for x in tag:
                     self.widgets[x].value = tag[x]
                 self.widgets['id'].value = id
