@@ -1,19 +1,16 @@
 from zope.interface import implements
 from Acquisition import aq_inner
-from zope.component import getMultiAdapter, getUtility, queryUtility
+from zope.component import getUtility, queryUtility
 from zope.schema.interfaces import IVocabularyFactory
 from plone.registry.interfaces import IRegistry
 
 from Products.Five import BrowserView
-from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 
 from plone.memoize import view
 
 from collective.imagetags.browser.interfaces import IImageTagsHelper
 from collective.imagetags.interfaces import IImageTagsSettings
 
-from collective.imagetags import imagetagsMessageFactory as _
-
 
 class ImageTagsHelper(BrowserView):
     """
