@@ -1,5 +1,6 @@
 from datetime import datetime
 from Acquisition import aq_inner
+import simplejson as json
 
 from Products.Five import BrowserView
 from zope.annotation.interfaces import IAnnotations
@@ -31,17 +32,17 @@ class ManageTags(BrowserView):
         """ This browser view can be called in a get/post request to remove 
             existing tags.
         """
-        context = self.context
         request = self.request
         if 'form.widgets.remove' in request.form:
             ids = request.form['form.widgets.remove'];
             removed = self._remove_tags(ids=ids)
             
             if 'ajax' in request.form:
-                array_id = [("'%s'" % id.encode('utf-8')) for id in ids]
-                result = '{removed: [%s]}' % ', '.join(array_id)
-                self.request.response.setHeader('content-type', 'text/javascript; charset=utf-8')
-                return result
+                request.response.setHeader('content-type', 'application/json; charset=utf-8')
+                response_body = {'removed': [id.encode('utf-8') for id in ids]}
+                response_http = json.dumps(response_body)
+                request.response.setHeader('content-length', len(response_http))
+                return response_http
             else:
                 count_removed = len(removed)
                 if count_removed==1:
