@@ -417,7 +417,7 @@ ImageTags = {
          */
 
         // Get the removed box/label and remove them
-        var json = eval('(' + data + ')');
+        var json = data;
         var removed = json.removed;
         jQuery.each(removed, function(pos, id) {
             var safeId = id.replace('.', '-');
